# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['xeofs', 'xeofs.models', 'xeofs.pandas', 'xeofs.utils', 'xeofs.xarray']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.22.2,<2.0.0',
 'pandas>=1.4.1,<2.0.0',
 'pooch>=1.6.0,<2.0.0',
 'scikit-learn>=1.0.2,<2.0.0',
 'xarray>=0.21.1,<0.22.0']

setup_kwargs = {
    'name': 'xeofs',
    'version': '0.4.0',
    'description': 'Collection of EOF analysis and related techniques for climate science',
    'long_description': '|badge1| |badge2| |badge3| |badge4| |badge5|\n\n.. |badge1| image:: https://img.shields.io/github/v/tag/nicrie/xeofs?label=Release\n    :alt: GitHub tag (latest SemVer)\n.. |badge2| image:: https://img.shields.io/github/workflow/status/nicrie/xeofs/CI\n   :alt: GitHub Workflow Status (event)\n.. |badge3| image:: https://readthedocs.org/projects/xeofs/badge/?version=latest\n   :target: https://xeofs.readthedocs.io/en/latest/?badge=latest\n   :alt: Documentation Status\n.. |badge4| image:: https://img.shields.io/pypi/dm/xeofs\n    :alt: PyPI - Downloads\n.. |badge5| image:: https://codecov.io/gh/nicrie/xeofs/branch/main/graph/badge.svg?token=8040ZDH6U7\n    :target: https://codecov.io/gh/nicrie/xeofs\n\n.. role:: red\n\n=================================\nxeofs: EOF analysis and variants\n=================================\nEmpirical orthogonal function (EOF) analysis, more commonly known as\nprincipal component analysis (PCA), is one of the most popular methods\nfor dimension reduction and structure identification in Earth system sciences.\nDue to this popularity, a number of different EOF variants have been developed\nover the last few years, either to mitigate some pitfalls of ordinary EOF\nanalysis (e.g. orthogonality, interpretability, linearity) or to broaden its\nscope (e.g. multivariate variants).\n\nCurrently, there are several implementations of EOF analysis on GitHub that\nfacilitate the acceptance and application of this method by the broader\nscientific community. Each of these implementations has its own strengths,\nwhich need to be highlighted (please `let me know`_, if I forgot any):\n\n\nEOF models\n-----------\n\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\nPackage                 eofs_       pyEOF_      xeof_       xMCA_       xmca2_      **xeofs**\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\nEOF analysis           ✅           ✅           ✅           ✅           ✅           ✅\nRotated EOF analysis   ❌           ✅           ❌           ❌           ✅           ✅\nComplex EOF analysis   ❌           ❌           ❌           ❌           ✅           ❌\nMultivariate EOF       ✅           ❌           ❌           ❌           ❌           ❌\nMCA                    ❌           ❌           ❌           ✅           ✅           ❌\nRotated MCA            ❌           ❌           ❌           ❌           ✅           ❌\nComplex MCA            ❌           ❌           ❌           ❌           ✅           ❌\nMultivariate MCA       ❌           ❌           ❌           ❌           ❌           ❌\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\n\n\nAdditional features\n----------------------\n\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\nPackage                 eofs_       pyEOF_      xeof_       xMCA_       xmca2_      **xeofs**\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\n``numpy`` interface    ✅           ❌           ❌           ❌           ✅           ✅\n``pandas`` interface   ❌           ❌           ❌           ❌           ❌           ✅\n``xarray`` interface   ?           ✅           ✅           ✅           ✅           ✅\nFast algorithm         ❌           ✅           ❌           ❌           ❌           ✅\nDask support           ✅           ❌           ✅           ❌           ❌           ❌\nArbitrary dimensions   ❌           ❌           ❌           ❌           ❌           ✅\n=====================  ==========  ==========  ==========  ==========  ==========  ==========\n\n\n.. _eofs: https://github.com/ajdawson/eofs\n.. _xeof: https://github.com/dougiesquire/xeof\n.. _xMCA: https://github.com/Yefee/xMCA\n.. _pyEOF: https://github.com/zzheng93/pyEOF\n.. _xmca2: https://github.com/nicrie/xmca\n\n.. _let me know: niclasrieger@gmail.com\n\n\nWhy ``xeofs``?\n----------------------\n\nThe goal of ``xeofs`` is to merge these different implementations and to simplify the integration of other existing and future variants of EOF analysis thanks to its modular code structure.\nThe official name is deliberately chosen to be similar to the other implementations to make it clear that ``xeofs`` is initially nothing revolutionary new in itself. The point is not to distinguish this implementation from the others, but rather to unify (+ extend) already existing implementations.\n\nThis project is intended to be a collaborative project of the scientific community and the contribution of EOF variants in the form of pull requests is explicitly encouraged.\nIf you are interested, just `contact me`_ or open an `Issue`_.\n\n.. _contact me: niclasrieger@gmail.com\n.. _Issue: https://github.com/nicrie/xeofs/issues\n\n\n\nInstallation\n----------------------\n\nThe package can be installed via\n\n.. code-block:: ini\n\n  pip install xeofs\n\n\nHow to use it?\n----------------------\nDocumentation_ is work in progress. Meanwhile check out some examples_ to get started:\n\nExamples:\n\n+ EOF analysis (S-mode_)\n+ EOF analysis (T-mode_)\n+ Rotated_ EOF analysis (Varimax, Promax)\n+ Weighted_ EOF analysis\n\n.. _T-mode: https://xeofs.readthedocs.io/en/latest/auto_examples/1uni/plot_eof-tmode.html#sphx-glr-auto-examples-1uni-plot-eof-tmode-py\n.. _S-mode: https://xeofs.readthedocs.io/en/latest/auto_examples/1uni/plot_eof-smode.html#sphx-glr-auto-examples-1uni-plot-eof-smode-py\n.. _Weighted: https://xeofs.readthedocs.io/en/latest/auto_examples/1uni/plot_weighted_eof.html#sphx-glr-auto-examples-1uni-plot-weighted-eof-py\n.. _Rotated: https://xeofs.readthedocs.io/en/latest/auto_examples/1uni/plot_rotated_eof.html#sphx-glr-auto-examples-1uni-plot-rotated-eof-py\n.. _Documentation: https://xeofs.readthedocs.io/en/latest/\n.. _examples: https://xeofs.readthedocs.io/en/latest/auto_examples/index.html\n\n\n************************\nCredits\n************************\n\n- Project folder structure: yngvem_\n- Testing data: xarray_ \\& pooch_\n\n\n.. _NumPy: https://www.numpy.org\n.. _pandas: https://pandas.pydata.org\n.. _xarray: https://xarray.pydata.org\n.. _yngvem: https://github.com/yngvem/python-project-structure\n.. _pooch: https://github.com/fatiando/pooch\n',
    'author': 'Niclas Rieger',
    'author_email': 'niclasrieger@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nicrie/xeofs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
